@@ -1,3 +1,6 @@
+/************************************************************
+Copyright (C) 2005 Masahiko SAWAI All Rights Reserved. 
+************************************************************/
 package sdl4gcj.input;
 
 import sdl4gcj.SDLException;
@@ -18,7 +21,7 @@ public class Joystick implements JoystickConstants
 		{
 			joysticks = new Joystick[Joystick.getNumJoysticks()];
 		}
-		else if (getNumJoysticks() > joysticks.length)
+		else if (Joystick.getNumJoysticks() > joysticks.length)
 		{
 			Joystick[] newArray = new Joystick[Joystick.getNumJoysticks()];
 			for (int i = 0;i < joysticks.length;i++)
