@@ -1,6 +1,11 @@
+/************************************************************
+Copyright (C) 2005 Masahiko SAWAI All Rights Reserved. 
+************************************************************/
 #include "sdl4gcj/input/Joystick.h"
 #include "sdl4gcj/SDLException.h"
 
+#include <java/lang/StringBuffer.h>
+
 #include <gcj/cni.h>
 #include <SDL.h>
 
@@ -8,6 +13,21 @@
 using namespace ::sdl4gcj::input;
 using namespace ::java::lang;
 
+// functions
+static
+inline
+::sdl4gcj::SDLException*
+createOpenFailedException(Joystick* joystick)
+{
+	StringBuffer* buffer = new StringBuffer();
+	buffer->append(JvNewStringLatin1("Joystick(index = "));
+	buffer->append(joystick->getIndex());
+	buffer->append(JvNewStringLatin1(") open failed : "));
+	buffer->append(JvNewStringLatin1(SDL_GetError()));
+	
+	return new sdl4gcj::SDLException(buffer->toString());
+}
+
 // class methods
 jint 
 Joystick::getNumJoysticks ()
@@ -47,8 +67,8 @@ Joystick::getName ()
 	nativeName = SDL_JoystickName(this->getIndex());
 	if (nativeName != NULL)
 	{
-		int bytesLength = strlen(nativeName);
-		jbyteArray byteArray = JvNewByteArray(bytesLength+1);
+		int bytesLength = strlen(nativeName)+1;
+		jbyteArray byteArray = JvNewByteArray(bytesLength);
 		jbyte* bytes = elements(byteArray);
 		strcpy((char*)bytes, nativeName);
 		name = new String(byteArray);
@@ -71,6 +91,8 @@ Joystick::open ()
 	{
 		SDL_Joystick* nativeJoystick;
 		nativeJoystick = SDL_JoystickOpen(this->getIndex());
+		if (nativeJoystick == NULL)
+			throw createOpenFailedException(this);
 		this->implementation = (::gnu::gcj::RawData*)nativeJoystick;
 	}
 }
