@@ -1,3 +1,6 @@
+/************************************************************
+Copyright (C) 2005 Masahiko SAWAI All Rights Reserved. 
+************************************************************/
 #include "sdl4gcj/mixer/Music.h"
 
 #include "sdl4gcj/SDLException.h"
@@ -20,13 +23,11 @@ createFreedMusicException()
 }
 
 // class methods
-
-/*
 Music*
 Music::loadMUS(::java::lang::String * filePath)
 {
 	JvInitClass(&Music::class$);
-	Music* result = NULL;
+	Music* music = NULL;
 
 	jbyteArray byteArray = filePath->getBytes();
 	int length = JvGetArrayLength(byteArray);
@@ -36,15 +37,14 @@ Music::loadMUS(::java::lang::String * filePath)
 	memcpy(buffer, bytes, length);
 	buffer[length] = '\0';
 
-	Mix_Music* music = Mix_LoadMUS(buffer);
-	if (music == NULL) throw new SDLException();
+	Mix_Music* nativeMusic = Mix_LoadMUS(buffer);
+	if (nativeMusic == NULL) throw new SDLException();
 
-	result = new Music();
-	result->implementation = (::gnu::gcj::RawData*)music;
+	music = new Music();
+	music->implementation = (::gnu::gcj::RawData*)nativeMusic;
 
-	return result;
+	return music;
 }
-*/
 
 // instance methods
 jint
@@ -68,22 +68,3 @@ Music::freeMusic()
 	return ;
 }
 
-void
-Music::loadMusicFromFile(::java::lang::String * filePath)
-{
-	JvInitClass(&Music::class$);
-
-	jbyteArray byteArray = filePath->getBytes();
-	int length = JvGetArrayLength(byteArray);
-	jbyte* bytes = elements(byteArray);
-	char buffer[length+1];
-
-	memcpy(buffer, bytes, length);
-	buffer[length] = '\0';
-
-	Mix_Music* nativeMusic = Mix_LoadMUS(buffer);
-	if (nativeMusic == NULL) throw new SDLException();
-	this->implementation = (::gnu::gcj::RawData*)nativeMusic;
-
-	return ;
-}
