@@ -1,5 +1,5 @@
 /************************************************************
-Copyright 2005 Masahiko SAWAI All Rights Reserved. 
+Copyright (C) 2005 Masahiko SAWAI All Rights Reserved. 
 ************************************************************/
 package sdl4gcj.ttf;
 
@@ -29,9 +29,9 @@ public class TTFSystem implements FontConstants
 
 	/**
 	* Initialize TTF subsystem.
-	* @return <code>0</code> if the TTF subsystem was initialized.
+	* If the TTF subsystem was initialized, SDLException occur.
 	**/
-	public static native int init();
+	public static native void init();
 		
 	/**
 	* Check TTF subsystem was already initialized.
