@@ -202,11 +202,7 @@ public class CDPlayerTest implements SDLConstants
 {
 	public static void main(String[] args)
 	{
-		if (SDLSystem.init(SDL_INIT_VIDEO|SDL_INIT_CDROM) != 0)
-		{
-			System.out.println("Init() fail");
-			System.exit(0);
-		}
+		SDLSystem.init(SDL_INIT_VIDEO|SDL_INIT_CDROM);
 
 		int index = -1;
 		if (args.length > 0)
