@@ -35,13 +35,7 @@ int main(int argc, char* argv[])
 		JvCreateJavaVM(NULL);
 		JvAttachCurrentThread(NULL, NULL);
 
-		if (SDLSystem::init(SDLSystemConstants::SDL_INIT_VIDEO) != 0)
-		{
-			fprintf(stderr, "SDL init fail.\n");
-			JvDetachCurrentThread();
-			return -1;
-		}
-		
+		SDLSystem::init(SDLSystemConstants::SDL_INIT_VIDEO);
 		Screen* screen = Screen::setVideoMode(640, 480, 24,
 			VideoConstants::SDL_SWSURFACE|VideoConstants::SDL_ANYFORMAT);
 
