@@ -578,18 +578,13 @@ public class JoystickTest
 	static final int WAIT_TIME = 30;
 	public static void main(String[] args)
 	{
-		if (SDLSystem.init(SDLSystem.SDL_INIT_VIDEO|SDLSystem.SDL_INIT_JOYSTICK) != 0)
-		{
-			System.out.println("Init() fail");
-			System.exit(0);
-		}
+		SDLSystem.init(SDLSystem.SDL_INIT_VIDEO|SDLSystem.SDL_INIT_JOYSTICK);
 
 		if (Joystick.getNumJoysticks() <= 0)
 		{
 			System.out.println("No Joystick Found");
 			System.exit(0);
 		}
-		
 
 		try
 		{
