@@ -75,11 +75,7 @@ public class PaletteTest
 
 	public static void main(String[] args)
 	{
-		if (SDLSystem.init(SDLSystem.SDL_INIT_VIDEO) != 0)
-		{
-			System.out.println("Init() fail");
-			System.exit(0);
-		}
+		SDLSystem.init(SDLSystem.SDL_INIT_VIDEO);
 
 		SDLOptionParser optParser = new SDLOptionParser(
 			640, 480, SCREEN_BPP, Surface.SDL_SWSURFACE);
