@@ -233,12 +233,7 @@ public class TestSprite implements SDLConstants
 	public static void main(String[] args)
 	{
 		
-		if (SDLSystem.init(SDL_INIT_VIDEO) != 0)
-		{
-			System.out.println("init fail.");
-			System.exit(0);
-		}
-
+		SDLSystem.init(SDL_INIT_VIDEO);
 		try
 		{
 			SDLOptionParser optionParser = new SDLOptionParser(640, 480, 8, SDL_SWSURFACE|SDL_ANYFORMAT);
