@@ -7,11 +7,7 @@ public class VideoInfoTest
 {
 	public static void main(String[] args)
 	{
-		if (SDLSystem.init(SDLSystem.SDL_INIT_VIDEO) != 0)
-		{
-			System.out.println("SDL_Init() fail : " );
-			System.exit(0);
-		}
+		SDLSystem.init(SDLSystem.SDL_INIT_VIDEO);
 
 		try
 		{
